==> uui-loader-0.0.8.tgz: package/lib/uui-loader.element.js <==
import { css, LitElement, html } from 'lit';

class UUILoaderElement extends LitElement {
  render() {
    return html`
      <div></div>
      <div></div>
      <div></div>
    `;
  }
}
UUILoaderElement.styles = [
  css`
      :host {
        /* currently this components color is defined through currentColor, if we like to use a different color, we need to implemenet a --uui-interface- color which will be set/overwritten when looks are set, aka. if this element is used within a button with the look danger, then this component would get an appropriate color. */
      }

      div {
        display: inline-block;
        width: var(--uui-size-base-unit,6px);
        height: var(--uui-size-base-unit,6px);
        border: 2px solid currentColor;
        border-radius: 100%;
        -webkit-animation: loaderAnimation 1.4s infinite;
                animation: loaderAnimation 1.4s infinite;
      }

      div:nth-child(1n) {
        -webkit-animation-delay: 0s;
                animation-delay: 0s;
      }

      div:nth-child(2n) {
        -webkit-animation-delay: 0.15s;
                animation-delay: 0.15s;
      }

      div:nth-child(3n) {
        -webkit-animation-delay: 0.3s;
                animation-delay: 0.3s;
      }

      @-webkit-keyframes loaderAnimation {
        0% {
          transform: scale(0.5);
          background-color: currentColor;
        }
        50% {
          transform: scale(1);
          background-color: transparent;
        }
        100% {
          transform: scale(0.5);
          background-color: currentColor;
        }
      }

      @keyframes loaderAnimation {
        0% {
          transform: scale(0.5);
          background-color: currentColor;
        }
        50% {
          transform: scale(1);
          background-color: transparent;
        }
        100% {
          transform: scale(0.5);
          background-color: currentColor;
        }
      }
    `
];

export { UUILoaderElement };

==> uui-loader-0.0.12.tgz: package/lib/uui-loader.element.js <==
import { css, LitElement, html } from 'lit';

class UUILoaderElement extends LitElement {
  render() {
    return html`
      <div></div>
      <div></div>
      <div></div>
    `;
  }
}
UUILoaderElement.styles = [
  css`
      :host {
        /* currently this components color is defined through currentColor, if we like to use a different color, we need to implemenet a --uui-interface- color which will be set/overwritten when looks are set, aka. if this element is used within a button with the look danger, then this component would get an appropriate color. */
      }

      div {
        display: inline-block;
        width: var(--uui-size-2,6px);
        height: var(--uui-size-2,6px);
        border: 2px solid currentColor;
        border-radius: 100%;
        -webkit-animation: loaderAnimation 1.4s infinite;
                animation: loaderAnimation 1.4s infinite;
      }

      div:nth-child(1n) {
        -webkit-animation-delay: 0s;
                animation-delay: 0s;
      }

      div:nth-child(2n) {
        -webkit-animation-delay: 0.15s;
                animation-delay: 0.15s;
      }

      div:nth-child(3n) {
        -webkit-animation-delay: 0.3s;
                animation-delay: 0.3s;
      }

      @-webkit-keyframes loaderAnimation {
        0% {
          transform: scale(0.5);
          background-color: currentColor;
        }
        50% {
          transform: scale(1);
          background-color: transparent;
        }
        100% {
          transform: scale(0.5);
          background-color: currentColor;
        }
      }

      @keyframes loaderAnimation {
        0% {
          transform: scale(0.5);
          background-color: currentColor;
        }
        50% {
          transform: scale(1);
          background-color: transparent;
        }
        100% {
          transform: scale(0.5);
          background-color: currentColor;
        }
      }
    `
];

export { UUILoaderElement };
